==> am_mod_lbr_0_3.zip: am_mod_lbr_0_3/components/lbr/template/barnraiser_01/revision_edit.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<style type="text/css">
<!--
@import url(<?php echo $template_path_core;?>css/aroundme_form.css);
-->
</style>

<script type="text/javascript" src="speller/spellChecker.js"></script>
<script type="text/javascript">
	function openSpellChecker() {
		var speller = new spellChecker();
		speller.spellCheckAll();
	}
</script>

<script language="JavaScript" type="text/javascript" src="<?php echo $template_path_core;?>/js/imageHandling.js"></script>

<form action="index.php?amn=lbr_revision_edit" method="post" name="frm" id="id_frm">
<input type="hidden" name="page_id" value="<?php if(isset($page['page_id'])) { echo $page['page_id'];}?>" />
<input type="hidden" name="set_id" value="<?php if(isset($page['set_id'])) { echo $page['set_id'];}?>" />


<div class="col_main">
	<div class="box">
		<div class="box_top">
			<span style="float:left">
				<img src="<?php echo $template_path_core;?>img/help.png" style="cursor:help;"  title="<?php echo $lang['txt_help'];?>" hspace="2" alt="" border="0" onClick="javascript:launchPopupWindow('components/core/help.php?help=core_wfg');" /><br />
			</span>
				
				<?php echo $lang['hdr_revise'];?><br />
		</div>
			
		<div class="box_mid">
			<div class="content">
				<p>
					<label for="id_revision_body"><?php echo $lang['txt_revision_body'];?></label><br />
					<textarea id="id_revision_body" name="revision_body" cols="70" rows="20" style="width:480px;"><?php echo $revision['revision_body'];?></textarea><br />
				</p>
				
				<?php
				$txtarea = "id_revision_body";
				$module_id = $core_config['module_id']['library'];
				include($template_path_core . "/inc/form_gui_html_editor.inc.php");
				?>
				
				<p>
					<label for="id_revision_note"><?php echo $lang['txt_revision_note'];?></label><br />
					<textarea name="revision_note" cols="70" rows="4" style="width:480px;"><?php echo $revision['revision_note'];?></textarea><br />
				</p>
				<hr />
					
				<p align="right">
					<input type="submit" name="preview_revision" id="id_sub_preview" class="input_submit" value="<?php echo $lang['sub_preview']; ?>" />
					<?php
					if (isset($allow_spellcheck)) {
					?>
					<input type="button" class="input_submit" value="<?php echo $lang['sub_check_spelling'];?>" onClick="openSpellChecker();" />
					<?php }?>
					
					<input name="insert_revision" type="submit" class="input_submit" value="<?php echo $lang['sub_insert'];?>" /><br />
				</p>
			
				<?php
				if (isset($revision['display_revision_body'])) {
				?>
				<p></p>
					<?php echo $revision['display_revision_body'];?><br />
				</p>
				<?php }?>
			</div>
		</div>
	</div>
</div>


<div class="col_side">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_page'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<b><?php echo $page['page_title'];?><br /></b><br />
				<?php echo $page['page_synopsis'];?><br />
				
				<p>
					<?php echo $lang['txt_wiki_name'];?>: <?php echo $page['page_name'];?><br />
				</p>
			</div>
		</div>
	</div>
</div>
</form>

==> am_mod_lbr_0_5.zip: am_mod_lbr_0_5/components/lbr/template/barnraiser_01/revision_edit.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<style type="text/css">
<!--
@import url(<?php echo $template_path_core;?>css/aroundme_form.css);
-->
</style>

<script type="text/javascript" src="speller/spellChecker.js"></script>
<script type="text/javascript">
	function openSpellChecker() {
		var speller = new spellChecker();
		speller.spellCheckAll();
	}
</script>

<script language="JavaScript" type="text/javascript" src="<?php echo $template_path_core;?>/js/imageHandling.js"></script>

<form action="index.php?amn=lbr_revision_edit" method="post" name="frm" id="id_frm">
<input type="hidden" name="page_id" value="<?php if(isset($page['page_id'])) { echo $page['page_id'];}?>" />
<input type="hidden" name="set_id" value="<?php if(isset($page['set_id'])) { echo $page['set_id'];}?>" />


<div class="col_main">
	<div class="box">
		<div class="box_top">
			<div class="content">
				<img src="<?php echo $template_path_core;?>img/help.png" style="cursor:help;float:left;"  title="<?php echo $lang['txt_help'];?>" hspace="2" alt="" border="0" onClick="javascript:launchPopupWindow('components/core/help.php?help=core_wfg');" /><br />
				
				<h1><?php echo $lang['hdr_revise'];?></h1>
			</div>
		</div>
			
		<div class="box_mid">
			<div class="content">
				<p>
					<label for="id_revision_body"><?php echo $lang['txt_revision_body'];?></label><br />
					<textarea id="id_revision_body" name="revision_body" cols="70" rows="20" style="width:480px;"><?php echo $revision['revision_body'];?></textarea><br />
				</p>
				
				<?php
				$txtarea = "id_revision_body";
				$module_id = $core_config['module_id']['library'];
				include($template_path_core . "/inc/form_gui_html_editor.inc.php");
				?>
				
				<p>
					<label for="id_revision_note"><?php echo $lang['txt_revision_note'];?></label><br />
					<textarea name="revision_note" cols="70" rows="4" style="width:480px;"><?php echo $revision['revision_note'];?></textarea><br />
				</p>
				<hr />
					
				<p align="right">
					<input type="submit" name="preview_revision" id="id_sub_preview" class="input_submit" value="<?php echo $lang['sub_preview']; ?>" />
					<?php
					if (isset($allow_spellcheck)) {
					?>
					<input type="button" class="input_submit" value="<?php echo $lang['sub_check_spelling'];?>" onClick="openSpellChecker();" />
					<?php }?>
					
					<input name="insert_revision" type="submit" class="input_submit" value="<?php echo $lang['sub_insert'];?>" /><br />
				</p>
			
				<?php
				if (isset($revision['display_revision_body'])) {
				?>
				<p></p>
					<?php echo $revision['display_revision_body'];?><br />
				</p>
				<?php }?>
			</div>
		</div>
	</div>
</div>


<div class="col_side">
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_page'];?></h1>
			</div>
		</div>
		
		<div class="box_mid">
			<div class="content">
				<b><?php echo $page['page_title'];?><br /></b><br />
				<?php echo $page['page_synopsis'];?><br />
				
				<p>
					<?php echo $lang['txt_wiki_name'];?>: <?php echo $page['page_name'];?><br />
				</p>
			</div>
		</div>
	</div>
</div>
</form>
